Re: [PATCH 2/4] fsmonitor: Don't bother pretty-printing JSON from watchman
- From
Johannes Schindelin <johannes.schindelin@gmx.de>
- Date
- Oct 27, 2017, 15:13 UTC
- Message-ID
- <alpine.DEB.2.21.1.1710271712020.6482@virtualbox>
- In-Reply-To
- <alpine.DEB.2.10.1710251722310.9817@alexmv-linux>
Hi Alex,
On Wed, 25 Oct 2017, Alex Vandiver wrote:
Show 5 quoted lines
> [Johannes asked about the speedup when using --no-pretty] > > ...so a modest 8% speedup. I note that those numbers are for a perl > with JSON::XS installed; without it installed, the runtime is so long > that I gave up waiting for it.
Very nice! AFAIR Git for Windows does *not* come with JSON::XS.
> Anyways, I'll put that in the commit message in the re-roll.
Thank you, Johannes